// @APIVersion 1.0.0
// @Title beego Test API
// @Description beego has a very cool tools to autogenerate documents for your API
// @Contact astaxie@gmail.com
// @TermsOfServiceUrl http://beego.me/
// @License Apache 2.0
// @LicenseUrl http://www.apache.org/licenses/LICENSE-2.0.html
package routers

import (
	"wechat-conf/controllers"
	"wechat-conf/controllers/autoreply"
	"wechat-conf/controllers/menu"
	"wechat-conf/controllers/sysorg"
	"wechat-conf/controllers/sysuser"
	"wechat-conf/controllers/wechatimg"
	"wechat-conf/controllers/wechatmenu"

	"github.com/astaxie/beego"
)

func RouteInit() {

	ns := beego.NewNamespace("/api",
		// 解决跨域时 先发送 options 问题
		beego.NSRouter("*", &controllers.BaseController{}, "options:Options"),
		// 登陆
		beego.NSRouter("/user/login", &controllers.UserController{}, "post:Login"),
		beego.NSNamespace("/admin",
			beego.NSRouter("/user/pwd", &controllers.UserController{}, "put:UpdatePassword"),
			beego.NSRouter("/user/sign", &controllers.UserController{}, "post:SignOut"),

			// 菜单
			beego.NSRouter("/menu", &menu.MenuController{}, "get:GetMenuList"),
			// 自动回复
			beego.NSRouter("/autoreply", &autoreply.AutoreplyController{}, "get:GetAutoReplyList"),
			beego.NSRouter("/autoreply/:autoreplyId", &autoreply.AutoreplyController{}, "get:GetAutoReplyById"),
			beego.NSRouter("/autoreply", &autoreply.AutoreplyController{}, "post:SaveAutoreply"),
			beego.NSRouter("/autoreply", &autoreply.AutoreplyController{}, "put:SaveAutoreply"),
			beego.NSRouter("/autoreply/:autoreplyId", &autoreply.AutoreplyController{}, "delete:DeleteAutoReply"),
			beego.NSRouter("/autoreply/isUse/:autoType/:isUse", &autoreply.AutoreplyController{}, "put:ChangeIsUse"),
			// 图片资源
			// beego.NSRouter("/wechatimg", &wechatimg.WechatImgController{}, "get:GetWechatImgList"),
			// beego.NSRouter("/wechatimg/sync", &wechatimg.WechatImgController{}, "put:SyncWechatImg"),
			// beego.NSRouter("/wechatimg", &wechatimg.WechatImgController{}, "post:AddNewImg"),
			// beego.NSRouter("/wechatimg/:mediaId", &wechatimg.WechatImgController{}, "delete:DeleteImg"),

			beego.NSRouter("/material/:type/count", &wechatimg.WechatImgController{}, "get:GetWechatImgCount"),
			beego.NSRouter("/material/:type", &wechatimg.WechatImgController{}, "get:GetWechatImgList"),
			beego.NSRouter("/material/:type/sync", &wechatimg.WechatImgController{}, "post:SyncWechatImg"),
			beego.NSRouter("/material/image/save", &wechatimg.WechatImgController{}, "post:AddNewImg"),
			beego.NSRouter("/material/:mediaId", &wechatimg.WechatImgController{}, "delete:DeleteImg"),

			// 用户管理
			beego.NSRouter("/sysuser", &sysuser.SysuserController{}, "get:GetUserList"),
			beego.NSRouter("/sysuser/:userId", &sysuser.SysuserController{}, "get:GetUserById"),
			beego.NSRouter("/sysuser", &sysuser.SysuserController{}, "post:SaveUser"),
			beego.NSRouter("/sysuser", &sysuser.SysuserController{}, "put:SaveUser"),
			beego.NSRouter("/sysuser/:userId", &sysuser.SysuserController{}, "delete:DeleteUser"),
			beego.NSRouter("/sysuser/bind/:userId/:orgId", &sysuser.SysuserController{}, "put:BindUser"),
			beego.NSRouter("/sysuser/unbind/:userId", &sysuser.SysuserController{}, "put:UnbindUser"),
			beego.NSRouter("/sysuser/pwd/:userId/:pwd", &sysuser.SysuserController{}, "put:ChangePassword"),
			beego.NSRouter("/sysuser/current", &sysuser.SysuserController{}, "get:GetCurrentUser"),
			beego.NSRouter("/sysuser/auth", &sysuser.SysuserController{}, "get:GetOrgAuth"),
			// 项目管理
			beego.NSRouter("/sysorg", &sysorg.SysorgController{}, "get:GetOrgList"),
			beego.NSRouter("/sysorg", &sysorg.SysorgController{}, "post:AddOrg"),
			beego.NSRouter("/sysorg", &sysorg.SysorgController{}, "put:AuthOrg"),
			beego.NSRouter("/sysorg/:orgId", &sysorg.SysorgController{}, "delete:DeleteOrg"),

			beego.NSRouter("/sysorg/:orgid/:confid", &sysorg.SysorgController{}, "put:OrgBindWechat"),

			// 文件
			beego.NSRouter("/file", &controllers.BaseController{}, "post:FileUpload"),
			beego.NSRouter("/file/base64", &controllers.BaseController{}, "post:UploadBase64Image"),
			// 微信菜单
			beego.NSRouter("/wechatmenu", &wechatmenu.MenuController{}, "get:GetMenuList"),
			beego.NSRouter("/wechatmenu", &wechatmenu.MenuController{}, "put:RefreshMenu"),

			// 微信
			beego.NSRouter("/authcode", &controllers.WechatController{}, "get:GetPreAuthCode"),
			beego.NSRouter("/wechat/conf/:code", &controllers.WechatController{}, "get:GetWechatByCode"),
		),

		beego.NSRouter("/ticket", &controllers.WechatController{}, "post:ComponentPush"),
		beego.NSRouter("/ticket", &controllers.WechatController{}, "get:ComponentPush"),
		beego.NSRouter("/:appid/callback", &controllers.WechatController{}, "get:WxReceive"),
		beego.NSRouter("/:appid/callback", &controllers.WechatController{}, "post:WxReceive"),
	)

	beego.AddNamespace(ns)
}
